
#ifndef  SystemAlg_H
#define SystemAlg_H

//#include "HecRunHeader2001v0.h"
#include "Headers.h"
//#include "HecEvent.h"
#include "Event.h"
#include "Geometry.h"






/*! -Class:    SystemAlg
  - Author:   Ian Gable (igable@uvic.ca)
  - Date:      06/04/2002
  - Description: SystemAlg is the base class for all UserAlg and all other algorithms. Each new
                      Algorithm created should inherit from this class. In the UserAlg class the SystemAlg
                      methods corresponding to those methods should also be called.  i.e. call
                      SystemAlg::initialize() in UserAlg::initialize().
  */
class SystemAlg {
public:

  /** The user should never need to use this contructor
    * @param event A pointer in the event. Information contained in the event
    *                             gets refreshed before the execute method is run
    * @param hecGeom Pointer to the singleton Geometry object
    * @param runHeader Pointer to the singleton HecRunHeader2001v0 object
    */

  SystemAlg(Event* event, Geometry* hecGeom, Headers* runHeader);

  //! Should be called inside UserAlg::initialize()
  virtual bool initialize();

  //! Should be called inside UserAlg::execute()
  virtual bool execute();

  //! Should be called inside UserAlg::finalize();
  virtual bool finalize();

  /** Before proceeding with your own class you should call this method from
  *    the constructor of UserAlg
  * @param algs A standard C++ STL Vector containing a list of SystemAlg
  *                          Derived Objects that will be run.
  */
  void setAlgs(vector<SystemAlg*> algs);

protected:
  void buildAlgList(vector<string> algList);

private:
  Event* m_event;
  Geometry* m_geo;
  Headers* m_runHeader;
  vector<SystemAlg*> m_algVector;

};

#endif
