#include "Event.h"

Event::Event()
{
}

//==========Hec Portion==================

bool Event::addHecCell(HecCell hecCell){
  m_hecCellVector.push_back(hecCell);
  return true;
}


HecCell* Event::hecCell(int adcNumber){
  if(adcNumber >= 1&& adcNumber <= m_hecCellVector.size()){
   return  &m_hecCellVector[adcNumber-1]; // note that we are returning a pointer to the cell
  } else {
    cout << "Cell accessed out of bounds; cell number: "
              << adcNumber << endl;
  }
}

void Event::clearHecCells()
{
  m_hecCellVector.clear();
  m_hecTriggerVector.clear();
}

int Event::numHecCells(){
  return m_hecCellVector.size();
}

const vector<HecCell>* Event::hecCellsPointer(){
  return &m_hecCellVector;
}

//note this method will crash if the length of the hecTrigger array changes
void Event::setHecTrigger(unsigned int hecTriggerArray[5]){
  for(int i = 0; i < 5; i++){
    m_hecTriggerVector.push_back(hecTriggerArray[i]);
  }
  processHecTrigger();
}

int Event::getHecTriggerBit(int bit){
  if(bit >= 0 && bit <=4){
    return m_hecTriggerVector[bit];
  } else {
    cout << "Trigger bits accessed out of bounds at:  "
          << bit << endl;
  }
}

void Event::processHecTrigger(){
  if(m_hecTriggerVector[4]){
    m_isHecRandom =true;
  } else {
    m_isHecRandom = false;
  }
  if(m_hecTriggerVector[3]) {
    m_isHecMuon = true;
  } else {
    m_isHecMuon = false;
  }
}

//====================== EmecPortion ============================

bool Event::addEmecCell(EmecCell emecCell){
  m_emecCellVector.push_back(emecCell);
  return true;
}


EmecCell* Event::emecCell(int adcNumber){
  if(adcNumber >= 0&& adcNumber < m_emecCellVector.size()){
   return  &m_emecCellVector[adcNumber];// note that we are returning a pointer to the cell
  } else {
    cout << "Cell accessed out of bounds; cell number: "
              << adcNumber << endl;
  }
}

void Event::clearEmecCells()
{
  m_emecCellVector.clear();
  m_emecTriggerVector.clear();
}

int Event::numEmecCells(){
  return m_emecCellVector.size();
}

const vector<EmecCell>* Event::emecCellsPointer(){
  return &m_emecCellVector;
}

//note this method will crash if the length of the hecTrigger array changes
void Event::setEmecTrigger(unsigned int emecTriggerArray[5]){
  for(int i = 0; i < 5; i++){
    m_emecTriggerVector.push_back(emecTriggerArray[i]);
  }
  processEmecTrigger();
}

int Event::getEmecTriggerBit(int bit){
  if(bit >= 0 && bit <=4){
    return m_emecTriggerVector[bit];
  } else {
    cout << "Trigger bits accessed out of bounds at:  "
          << bit << endl;
  }
}

void Event::processEmecTrigger(){
  if(m_emecTriggerVector[4]){
    m_isEmecRandom =true;
  } else {
    m_isEmecRandom = false;
  }
  if(m_emecTriggerVector[3]) {
    m_isEmecMuon = true;
  } else {
    m_isEmecMuon = false;
  }
}

void Event::setBeamChamberInfo(float slope[2], float pos0[2], float xcov[3], float ycov[3]){
  m_bcSlopeX = slope[0];
  m_bcSlopeY = slope[1];
  m_bcXatZ0 = pos0[0];
  m_bcYatZ0 = pos0[1];

  m_bcCovXatZ0 =xcov[0];
  m_bcCovXatSlopeX =xcov[1];
  m_bcCovXatZ0SlopeX =xcov[2];

  m_bcCovYatZ0 = ycov[0];
  m_bcCovYatSlopeY = ycov[1];
  m_bcCovYatZ0SlopeY = ycov[2];
}

vector<float> Event::beamChamberLine(){
  vector<float> beam;
  beam.push_back(m_bcXatZ0);
  beam.push_back(m_bcYatZ0);
  beam.push_back(m_bcSlopeX);
  beam.push_back(m_bcSlopeY);
  return beam;
}

