
#include "HecEnergyLayerAlg.h"
#include "TBrowser.h"
#include "TRootBrowser.h"
#include "TROOT.h"

#include <sstream>
#include <string>
#include <iostream>

using std::cin;
using std::string;

HecEnergyLayerAlg::HecEnergyLayerAlg(Event* event, Geometry* geo, Headers* runHeader)
:SystemAlg(event,geo,runHeader){
  m_event = event;
  m_geo = geo;
  m_runHeader = runHeader;
  m_interactive = true;
}

HecEnergyLayerAlg::~HecEnergyLayerAlg(){
  for(int i =0; i < 4; i++){
    delete energy[i];
  }
  delete profile;
}

// initialize any variables here
bool HecEnergyLayerAlg::initialize(){
  cout << "HecEnergyLayerAlg::initialize()\n" ;
  string runNumber(" Run Number: " );
  int junk;

  //this little chunk does the type conversion
  std::ostringstream os1;
  os1  << runNumber << " " << m_runHeader->global()->getRunNo() << " Profile by layer";
  cout << "Preflush: " << os1.str() << "\n";
  os1.clear();
  cout << "Postflush: " << os1.str() << "\n";
  runNumber= os1.str();

  //instaciate the profile histograms and the canvas for it
  for(int i =0; i < 4; i++){
    std::ostringstream os2;
    os2 << "Layer " << i+1;
    energy[i] = new  TH1F("energy",  os2.str().c_str() ,200, -5,800);  //
  }

  profile = new TProfile("Profile", runNumber.c_str(),4,0,4,0,500,"s");

  return true;

}

// put any code you want executed per event here
bool HecEnergyLayerAlg::execute(){

  float energySum[4] = {0,0,0,0} ;
  for(int i = 1; i <= m_event->numHecCells(); i++){
   // energySum[m_hecGeo->hec_iz(i)-1] += m_event->hecCell(i)->signal();
  }

  for(int i = 0; i < 4; i++){
        energy[i]->Fill(energySum[i]);
  }

  profile->Fill( 0.5,energySum[0]  );
  profile->Fill( 1.5,energySum[1]  );
  profile->Fill( 2.5,energySum[2]  );
  profile->Fill( 3.5,energySum[3]  );


  return true;
}

//Wrap up anything you wanted done after all the events have been run
// ie Draw your histograms etc
bool HecEnergyLayerAlg::finalize(){
  cout << "HecEnergyLayerAlg::finalize()\n";

  TCanvas can("Energy", "Energy Canvas",800,600);
  can.Divide(3,2);
  for(int i = 0; i < 4; i++){
    can.cd(i+1);
    energy[i]->Draw();
  }
  can.cd(5);
  profile->Draw();// draw the energy histogram
  can.Update();

   gROOT->GetListOfBrowsables()->Add(profile);
   //TRootBrowser *imp = (TRootBrowser *)b->GetBrowserImp();
    //imp->Connect("DoubleClicked(TObject*)",0,0,"PrintObj(TObject*)");

  if(m_interactive){
    string choice;
    cout << "Output plot to postscript file (y/n): ";
    cin >> choice;
    if(choice == "y"){
      can.Print("HecEnergyLayer.ps") ;
      cout << "\nFile output to HecEnergyLayer.ps'\n";
    } else {
      cout << "Finished!\n";
    }
  }

  std::ostringstream os;
  os << m_runHeader->global()->getRunNo() << "_EnergyLayer.root";
  TFile file(os.str().c_str(), "recreate");
  can.Write();
  file.Close();

  return true;
}
